Tutorial: learning Kwant through examples
=========================================

.. toctree::
    introduction
    first_steps
    spin_potential_shape
    spectrum
    graphene
    superconductors
    operators
    plotting
    kpm
    discretize
    faq
